<template>
  <common-dialog
    :title="title"
    class="point_dialog"
    :visible="pointDialogVisible"
    :before-close="beforeClosePointDialog"
    destroy-on-close
  >
    <div class="dialog-body-border" v-if="modelResult.length">
      <div style="width:100%;height:40px;">
        <span style="font-size:14px;color:#c0c4cc;margin-right:5px"
          >调度时间</span
        >
        <el-date-picker
          v-model="dateTime"
          type="datetimerange"
          unlink-panels
          range-separator="—"
          start-placeholder="请选择开始日期"
          end-placeholder="请选择结束日期"
          value-format="yyyy-MM-dd HH:mm:ss"
          style="width:350px"
        >
        </el-date-picker>
        <el-button
          style="margin-left: 10px"
          size="small"
          type="primary"
          icon="el-icon-search"
          @click="loadData"
          >搜索</el-button
        >
      </div>
      <el-table
        :data="data"
        stripe
        style="width: 100%"
        height="calc(100% - 70px)"
      >
        <el-table-column
          :scoped-slot="item.paramWidth ? null : renderHeader"
          v-for="item of modelResult"
          :key="item.paraCode"
          :prop="item.paramCode"
          :label="item.paramName"
          :min-width="item.paramWidth"
          :show-overflow-tooltip="true"
          align="center"
        ></el-table-column>
      </el-table>
      <div style="width:100%;margin-top:5px">
        <el-pagination
          style="float:right"
          small
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
          :current-page="currentPage"
          :pager-count="11"
          :page-sizes="[10, 20, 50, 100, 200, 300, 500]"
          :page-size="50"
          layout="total, sizes, prev, pager, next, jumper"
          :total="total"
        >
        </el-pagination>
      </div>
    </div>

    <div v-else class="dialog-body-border bgcolor">
      <div>请联系管理员，配置模型出参数据</div>
      <!-- <div>{{ message }}</div> -->
    </div>
    <div slot="footer" style="text-align: right">
      <el-button size="small" @click="beforeClosePointDialog">关闭</el-button>
    </div>
  </common-dialog>
</template>

<script>
export default {
  name: 'point-dialog',
  data() {
    return {
      dateTime: [],
      title: '',
      data: [],
      currentPage: 1, //当前页
      pageSize: 50, //每页多少条
      total: 0, //总条数
      filters: [
        {text: '布尔', value: 'B'},
        {text: '浮点', value: 'F'},
        {text: '整型', value: 'I'}
      ],
      pointDialogVisible: false,
      currentSys: {},
      fanCode: '', //机组编号
      modelId: '', //模型ID
      modelResult: [] //执行结果
      // message: ''
    }
  },
  methods: {
    open(model) {
      this.title = model.fanCode + '-' + model.modelName
      this.modelId = model.modelId
      this.fanCode = model.fanCode
      this.pointDialogVisible = true
      this.loadData()
    },
    renderHeader(h, {column}) {
      // console.log(column)
      if (column.label.length && column.label.length < 4) {
        column.minWidth = 50
      } else {
        column.minWidth = column.label.length * 16
      }
      return h(
        'div',
        {
          class: 'table-header'
        },
        [column.label]
      )
    },
    beforeClosePointDialog() {
      this.pointDialogVisible = false
      this.dateTime = []
      this.data = []
      this.modelResult = []
      this.currentPage = 1
      this.pageSize = 50
      this.total = 0
    },
    loadData() {
      let param = {
        pageBean: {
          page: this.currentPage,
          pageSize: this.pageSize,
          total: this.total
        },
        sorter: [
          {
            direction: 'DESC',
            property: 'create_time_'
          }
        ]
      }
      let idQuerys = [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'fan_code_',
          relation: 'AND',
          value: this.fanCode
        }
      ]
      let dateQuerys = [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'scheduler_time_',
          relation: 'AND',
          value: this.dateTime
        }
      ]
      if (param.querys && param.querys.length) {
        param.querys.push(...idQuerys)
      } else {
        param.querys = idQuerys
      }
      if (this.dateTime && this.dateTime.length) {
        param.querys.push(...dateQuerys)
      }

      this.$http
        .post(
          '${cssc}/biz/model/modelInfo/v1/modelResult/sliceQueryModelResult?modelId=' +
            this.modelId,
          param
        )
        .then(
          res => {
            // console.log(res)
            let resp = res.data
            let rows = resp.rows
            this.data = rows
            this.currentPage = resp.page
            this.pageSize = resp.pageSize
            this.total = resp.total
          },
          error => {
            reject(error)
          }
        )
      let param2 = {
        pageBean: {
          page: 1,
          pageSize: 50,
          total: 0
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'modelId',
            relation: 'AND',
            value: this.modelId
          },
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'paramType',
            relation: 'AND',
            value: 'result'
          }
        ],
        sorter: [
          {
            direction: 'ASC',
            property: 'sn'
          }
        ]
      }
      this.$http
        .post(
          '${cssc}/biz/model/modelInfo/v1/modelParams/queryParamByModel',
          param2
        )
        .then(
          res => {
            // console.log(res.data)
            this.modelResult = res.data
          },
          err => {
            reject(err)
          }
        )
    },
    handleSizeChange(val) {
      this.pageSize = val
      this.loadData()
    },
    handleCurrentChange(val) {
      this.currentPage = val
      this.loadData()
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
.point_dialog /deep/ .el-dialog__body {
  height: calc(90vh - 180px);
}
.point_dialog /deep/ .inputs {
  width: 400px;
}
.point_dialog /deep/ .el-dialog {
  width: 85% !important;
}
/deep/ .el-range-editor--small.el-input__inner,
/deep/ .el-date-editor .el-range-input {
  background-color: $--background-color-secondary;
}
/deep/ .el-range-separator,
/deep/ .el-date-editor .el-range-input {
  color: $--color-text-placeholder;
}
/deep/ .el-table__body-wrapper {
  max-height: calc(100% - 38px) !important;
}
/deep/ .el-table .cell {
  padding-left: 0;
  padding-right: 0;
}
/deep/ .el-table .cell .table-header {
  width: 100% !important;
  box-sizing: border-box;
}
.dialog-body-border {
  height: calc(100% - 10px);
  width: 100%;
  // border: 1px solid rgba(238, 238, 238, 0.459);
}
/deep/ .el-input--mini .el-input__inner {
  height: 22px;
  line-height: 22px;
}
/deep/ .el-table__body-wrapper {
  background: transparent;
}
/deep/ .el-table {
  background: transparent;
}
.bgcolor {
  background-color: $--background-color-secondary;
  div {
    color: $--color-info;
    text-align: center;
    padding-top: 200px;
  }
}
</style>
